@@ -1,4 +1,4 @@
-import logging
+import inspect
 import os.path
 import random
 import string
@@ -7,10 +7,9 @@ import traceback
 import uuid
 from copy import deepcopy
 from functools import reduce
+from importlib.util import spec_from_file_location, module_from_spec
 from itertools import groupby
 from typing import List, Dict, Union
-import inspect
-from importlib.util import spec_from_file_location, module_from_spec
 
 from lesscode_utils.encryption_algorithm import MD5
 
@@ -218,7 +217,7 @@ def str2short_str(value: str, n: int = 5, chars=string.ascii_letters + string.di
 
 
 def eliminate_empty(data: list):
-    return [x for x in data if x is not None]
+    return [x for x in data if x not in [None, '', 'NULL']]
 
 
 def find_child(data, key="id", parent_key="parent_id"):
